@@ -1,5 +1,5 @@
 package Object::Enum;
-
+$Object::Enum::VERSION = '0.073';
 use strict;
 use warnings;
 use 5.006001;
@@ -42,14 +42,6 @@ sub _build_enum {
 
 Object::Enum - replacement for C<< if ($foo eq 'bar') >>
 
-=head1 VERSION
-
-Version 0.072
-
-=cut
-
-our $VERSION = '0.072';
-
 =head1 SYNOPSIS
 
   use Object::Enum qw(Enum);
@@ -303,6 +295,10 @@ L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Object-Enum>
 
 L<http://search.cpan.org/dist/Object-Enum>
 
+=item * GitHub
+
+L<https://github.com/jmmills/object-enum/>
+
 =back
 
 =head1 ACKNOWLEDGEMENTS
